import typing

import typing_extensions

_list = list

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleCloudDataplexV1Action(typing_extensions.TypedDict, total=False):
    asset: str
    category: typing_extensions.Literal[
        "CATEGORY_UNSPECIFIED",
        "RESOURCE_MANAGEMENT",
        "SECURITY_POLICY",
        "DATA_DISCOVERY",
    ]
    dataLocations: _list[str]
    detectTime: str
    failedSecurityPolicyApply: GoogleCloudDataplexV1ActionFailedSecurityPolicyApply
    incompatibleDataSchema: GoogleCloudDataplexV1ActionIncompatibleDataSchema
    invalidDataFormat: GoogleCloudDataplexV1ActionInvalidDataFormat
    invalidDataOrganization: GoogleCloudDataplexV1ActionInvalidDataOrganization
    invalidDataPartition: GoogleCloudDataplexV1ActionInvalidDataPartition
    issue: str
    lake: str
    missingData: GoogleCloudDataplexV1ActionMissingData
    missingResource: GoogleCloudDataplexV1ActionMissingResource
    name: str
    unauthorizedResource: GoogleCloudDataplexV1ActionUnauthorizedResource
    zone: str

@typing.type_check_only
class GoogleCloudDataplexV1ActionFailedSecurityPolicyApply(
    typing_extensions.TypedDict, total=False
):
    asset: str

@typing.type_check_only
class GoogleCloudDataplexV1ActionIncompatibleDataSchema(
    typing_extensions.TypedDict, total=False
):
    existingSchema: str
    newSchema: str
    sampledDataLocations: _list[str]
    schemaChange: typing_extensions.Literal[
        "SCHEMA_CHANGE_UNSPECIFIED", "INCOMPATIBLE", "MODIFIED"
    ]
    table: str

@typing.type_check_only
class GoogleCloudDataplexV1ActionInvalidDataFormat(
    typing_extensions.TypedDict, total=False
):
    expectedFormat: str
    newFormat: str
    sampledDataLocations: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1ActionInvalidDataOrganization(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDataplexV1ActionInvalidDataPartition(
    typing_extensions.TypedDict, total=False
):
    expectedStructure: typing_extensions.Literal[
        "PARTITION_STRUCTURE_UNSPECIFIED", "CONSISTENT_KEYS", "HIVE_STYLE_KEYS"
    ]

@typing.type_check_only
class GoogleCloudDataplexV1ActionMissingData(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDataplexV1ActionMissingResource(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDataplexV1ActionUnauthorizedResource(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDataplexV1Asset(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    discoverySpec: GoogleCloudDataplexV1AssetDiscoverySpec
    discoveryStatus: GoogleCloudDataplexV1AssetDiscoveryStatus
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    resourceSpec: GoogleCloudDataplexV1AssetResourceSpec
    resourceStatus: GoogleCloudDataplexV1AssetResourceStatus
    securityStatus: GoogleCloudDataplexV1AssetSecurityStatus
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetDiscoverySpec(typing_extensions.TypedDict, total=False):
    csvOptions: GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions
    enabled: bool
    excludePatterns: _list[str]
    includePatterns: _list[str]
    jsonOptions: GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
    schedule: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions(
    typing_extensions.TypedDict, total=False
):
    delimiter: str
    disableTypeInference: bool
    encoding: str
    headerRows: int

@typing.type_check_only
class GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions(
    typing_extensions.TypedDict, total=False
):
    disableTypeInference: bool
    encoding: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetDiscoveryStatus(
    typing_extensions.TypedDict, total=False
):
    lastRunDuration: str
    lastRunTime: str
    message: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "SCHEDULED", "IN_PROGRESS", "PAUSED", "DISABLED"
    ]
    stats: GoogleCloudDataplexV1AssetDiscoveryStatusStats
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetDiscoveryStatusStats(
    typing_extensions.TypedDict, total=False
):
    dataItems: str
    dataSize: str
    filesets: str
    tables: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetResourceSpec(typing_extensions.TypedDict, total=False):
    name: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "STORAGE_BUCKET", "BIGQUERY_DATASET"
    ]

@typing.type_check_only
class GoogleCloudDataplexV1AssetResourceStatus(
    typing_extensions.TypedDict, total=False
):
    message: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "READY", "ERROR"]
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetSecurityStatus(
    typing_extensions.TypedDict, total=False
):
    message: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "READY", "APPLYING", "ERROR"]
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1AssetStatus(typing_extensions.TypedDict, total=False):
    activeAssets: int
    securityPolicyApplyingAssets: int
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1CancelJobRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDataplexV1Content(typing_extensions.TypedDict, total=False):
    createTime: str
    dataText: str
    description: str
    labels: dict[str, typing.Any]
    name: str
    notebook: GoogleCloudDataplexV1ContentNotebook
    path: str
    sqlScript: GoogleCloudDataplexV1ContentSqlScript
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1ContentNotebook(typing_extensions.TypedDict, total=False):
    kernelType: typing_extensions.Literal["KERNEL_TYPE_UNSPECIFIED", "PYTHON3"]

@typing.type_check_only
class GoogleCloudDataplexV1ContentSqlScript(typing_extensions.TypedDict, total=False):
    engine: typing_extensions.Literal["QUERY_ENGINE_UNSPECIFIED", "SPARK"]

@typing.type_check_only
class GoogleCloudDataplexV1DiscoveryEvent(typing_extensions.TypedDict, total=False):
    action: GoogleCloudDataplexV1DiscoveryEventActionDetails
    assetId: str
    config: GoogleCloudDataplexV1DiscoveryEventConfigDetails
    dataLocation: str
    entity: GoogleCloudDataplexV1DiscoveryEventEntityDetails
    lakeId: str
    message: str
    partition: GoogleCloudDataplexV1DiscoveryEventPartitionDetails
    type: typing_extensions.Literal[
        "EVENT_TYPE_UNSPECIFIED",
        "CONFIG",
        "ENTITY_CREATED",
        "ENTITY_UPDATED",
        "ENTITY_DELETED",
        "PARTITION_CREATED",
        "PARTITION_UPDATED",
        "PARTITION_DELETED",
    ]
    zoneId: str

@typing.type_check_only
class GoogleCloudDataplexV1DiscoveryEventActionDetails(
    typing_extensions.TypedDict, total=False
):
    type: str

@typing.type_check_only
class GoogleCloudDataplexV1DiscoveryEventConfigDetails(
    typing_extensions.TypedDict, total=False
):
    parameters: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDataplexV1DiscoveryEventEntityDetails(
    typing_extensions.TypedDict, total=False
):
    entity: str
    type: typing_extensions.Literal["ENTITY_TYPE_UNSPECIFIED", "TABLE", "FILESET"]

@typing.type_check_only
class GoogleCloudDataplexV1DiscoveryEventPartitionDetails(
    typing_extensions.TypedDict, total=False
):
    entity: str
    partition: str
    sampledDataLocations: _list[str]
    type: typing_extensions.Literal["ENTITY_TYPE_UNSPECIFIED", "TABLE", "FILESET"]

@typing.type_check_only
class GoogleCloudDataplexV1Entity(typing_extensions.TypedDict, total=False):
    asset: str
    catalogEntry: str
    compatibility: GoogleCloudDataplexV1EntityCompatibilityStatus
    createTime: str
    dataPath: str
    dataPathPattern: str
    description: str
    displayName: str
    etag: str
    format: GoogleCloudDataplexV1StorageFormat
    id: str
    name: str
    schema: GoogleCloudDataplexV1Schema
    system: typing_extensions.Literal[
        "STORAGE_SYSTEM_UNSPECIFIED", "CLOUD_STORAGE", "BIGQUERY"
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "TABLE", "FILESET"]
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1EntityCompatibilityStatus(
    typing_extensions.TypedDict, total=False
):
    bigquery: GoogleCloudDataplexV1EntityCompatibilityStatusCompatibility
    hiveMetastore: GoogleCloudDataplexV1EntityCompatibilityStatusCompatibility

@typing.type_check_only
class GoogleCloudDataplexV1EntityCompatibilityStatusCompatibility(
    typing_extensions.TypedDict, total=False
):
    compatible: bool
    reason: str

@typing.type_check_only
class GoogleCloudDataplexV1Environment(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    displayName: str
    endpoints: GoogleCloudDataplexV1EnvironmentEndpoints
    infrastructureSpec: GoogleCloudDataplexV1EnvironmentInfrastructureSpec
    labels: dict[str, typing.Any]
    name: str
    sessionSpec: GoogleCloudDataplexV1EnvironmentSessionSpec
    sessionStatus: GoogleCloudDataplexV1EnvironmentSessionStatus
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentEndpoints(
    typing_extensions.TypedDict, total=False
):
    notebooks: str
    sql: str

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentInfrastructureSpec(
    typing_extensions.TypedDict, total=False
):
    compute: GoogleCloudDataplexV1EnvironmentInfrastructureSpecComputeResources
    osImage: GoogleCloudDataplexV1EnvironmentInfrastructureSpecOsImageRuntime

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentInfrastructureSpecComputeResources(
    typing_extensions.TypedDict, total=False
):
    diskSizeGb: int
    maxNodeCount: int
    nodeCount: int

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentInfrastructureSpecOsImageRuntime(
    typing_extensions.TypedDict, total=False
):
    imageVersion: str
    javaLibraries: _list[str]
    properties: dict[str, typing.Any]
    pythonPackages: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentSessionSpec(
    typing_extensions.TypedDict, total=False
):
    enableFastStartup: bool
    maxIdleDuration: str

@typing.type_check_only
class GoogleCloudDataplexV1EnvironmentSessionStatus(
    typing_extensions.TypedDict, total=False
):
    active: bool

@typing.type_check_only
class GoogleCloudDataplexV1Job(typing_extensions.TypedDict, total=False):
    endTime: str
    message: str
    name: str
    retryCount: int
    service: typing_extensions.Literal["SERVICE_UNSPECIFIED", "DATAPROC"]
    serviceJob: str
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "RUNNING",
        "CANCELLING",
        "CANCELLED",
        "SUCCEEDED",
        "FAILED",
        "ABORTED",
    ]
    uid: str

@typing.type_check_only
class GoogleCloudDataplexV1JobEvent(typing_extensions.TypedDict, total=False):
    endTime: str
    jobId: str
    message: str
    retries: int
    service: typing_extensions.Literal["SERVICE_UNSPECIFIED", "DATAPROC"]
    serviceJob: str
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "SUCCEEDED", "FAILED", "CANCELLED", "ABORTED"
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "SPARK", "NOTEBOOK"]

@typing.type_check_only
class GoogleCloudDataplexV1Lake(typing_extensions.TypedDict, total=False):
    assetStatus: GoogleCloudDataplexV1AssetStatus
    createTime: str
    description: str
    displayName: str
    labels: dict[str, typing.Any]
    metastore: GoogleCloudDataplexV1LakeMetastore
    metastoreStatus: GoogleCloudDataplexV1LakeMetastoreStatus
    name: str
    serviceAccount: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1LakeMetastore(typing_extensions.TypedDict, total=False):
    service: str

@typing.type_check_only
class GoogleCloudDataplexV1LakeMetastoreStatus(
    typing_extensions.TypedDict, total=False
):
    endpoint: str
    message: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "NONE", "READY", "UPDATING", "ERROR"
    ]
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1ListActionsResponse(
    typing_extensions.TypedDict, total=False
):
    actions: _list[GoogleCloudDataplexV1Action]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListAssetsResponse(typing_extensions.TypedDict, total=False):
    assets: _list[GoogleCloudDataplexV1Asset]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListContentResponse(
    typing_extensions.TypedDict, total=False
):
    content: _list[GoogleCloudDataplexV1Content]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListEntitiesResponse(
    typing_extensions.TypedDict, total=False
):
    entities: _list[GoogleCloudDataplexV1Entity]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListEnvironmentsResponse(
    typing_extensions.TypedDict, total=False
):
    environments: _list[GoogleCloudDataplexV1Environment]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[GoogleCloudDataplexV1Job]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDataplexV1ListLakesResponse(typing_extensions.TypedDict, total=False):
    lakes: _list[GoogleCloudDataplexV1Lake]
    nextPageToken: str
    unreachableLocations: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1ListPartitionsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    partitions: _list[GoogleCloudDataplexV1Partition]

@typing.type_check_only
class GoogleCloudDataplexV1ListSessionsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    sessions: _list[GoogleCloudDataplexV1Session]

@typing.type_check_only
class GoogleCloudDataplexV1ListTasksResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    tasks: _list[GoogleCloudDataplexV1Task]
    unreachableLocations: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1ListZonesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    zones: _list[GoogleCloudDataplexV1Zone]

@typing.type_check_only
class GoogleCloudDataplexV1OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class GoogleCloudDataplexV1Partition(typing_extensions.TypedDict, total=False):
    etag: str
    location: str
    name: str
    values: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1Schema(typing_extensions.TypedDict, total=False):
    fields: _list[GoogleCloudDataplexV1SchemaSchemaField]
    partitionFields: _list[GoogleCloudDataplexV1SchemaPartitionField]
    partitionStyle: typing_extensions.Literal[
        "PARTITION_STYLE_UNSPECIFIED", "HIVE_COMPATIBLE"
    ]
    userManaged: bool

@typing.type_check_only
class GoogleCloudDataplexV1SchemaPartitionField(
    typing_extensions.TypedDict, total=False
):
    name: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "BOOLEAN",
        "BYTE",
        "INT16",
        "INT32",
        "INT64",
        "FLOAT",
        "DOUBLE",
        "DECIMAL",
        "STRING",
        "BINARY",
        "TIMESTAMP",
        "DATE",
        "TIME",
        "RECORD",
        "NULL",
    ]

@typing.type_check_only
class GoogleCloudDataplexV1SchemaSchemaField(typing_extensions.TypedDict, total=False):
    description: str
    fields: _list[GoogleCloudDataplexV1SchemaSchemaField]
    mode: typing_extensions.Literal[
        "MODE_UNSPECIFIED", "REQUIRED", "NULLABLE", "REPEATED"
    ]
    name: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "BOOLEAN",
        "BYTE",
        "INT16",
        "INT32",
        "INT64",
        "FLOAT",
        "DOUBLE",
        "DECIMAL",
        "STRING",
        "BINARY",
        "TIMESTAMP",
        "DATE",
        "TIME",
        "RECORD",
        "NULL",
    ]

@typing.type_check_only
class GoogleCloudDataplexV1Session(typing_extensions.TypedDict, total=False):
    createTime: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    userId: str

@typing.type_check_only
class GoogleCloudDataplexV1SessionEvent(typing_extensions.TypedDict, total=False):
    eventSucceeded: bool
    message: str
    query: GoogleCloudDataplexV1SessionEventQueryDetail
    sessionId: str
    type: typing_extensions.Literal[
        "EVENT_TYPE_UNSPECIFIED", "START", "STOP", "QUERY", "CREATE"
    ]
    unassignedDuration: str
    userId: str
    warmPoolEnabled: bool

@typing.type_check_only
class GoogleCloudDataplexV1SessionEventQueryDetail(
    typing_extensions.TypedDict, total=False
):
    dataProcessedBytes: str
    duration: str
    engine: typing_extensions.Literal["ENGINE_UNSPECIFIED", "SPARK_SQL", "BIGQUERY"]
    queryId: str
    queryText: str
    resultSizeBytes: str

@typing.type_check_only
class GoogleCloudDataplexV1StorageFormat(typing_extensions.TypedDict, total=False):
    compressionFormat: typing_extensions.Literal[
        "COMPRESSION_FORMAT_UNSPECIFIED", "GZIP", "BZIP2"
    ]
    csv: GoogleCloudDataplexV1StorageFormatCsvOptions
    format: typing_extensions.Literal[
        "FORMAT_UNSPECIFIED",
        "PARQUET",
        "AVRO",
        "ORC",
        "CSV",
        "JSON",
        "IMAGE",
        "AUDIO",
        "VIDEO",
        "TEXT",
        "TFRECORD",
        "OTHER",
        "UNKNOWN",
    ]
    json: GoogleCloudDataplexV1StorageFormatJsonOptions
    mimeType: str

@typing.type_check_only
class GoogleCloudDataplexV1StorageFormatCsvOptions(
    typing_extensions.TypedDict, total=False
):
    delimiter: str
    encoding: str
    headerRows: int
    quote: str

@typing.type_check_only
class GoogleCloudDataplexV1StorageFormatJsonOptions(
    typing_extensions.TypedDict, total=False
):
    encoding: str

@typing.type_check_only
class GoogleCloudDataplexV1Task(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    displayName: str
    executionSpec: GoogleCloudDataplexV1TaskExecutionSpec
    executionStatus: GoogleCloudDataplexV1TaskExecutionStatus
    labels: dict[str, typing.Any]
    name: str
    notebook: GoogleCloudDataplexV1TaskNotebookTaskConfig
    spark: GoogleCloudDataplexV1TaskSparkTaskConfig
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    triggerSpec: GoogleCloudDataplexV1TaskTriggerSpec
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskExecutionSpec(typing_extensions.TypedDict, total=False):
    args: dict[str, typing.Any]
    kmsKey: str
    maxJobExecutionLifetime: str
    project: str
    serviceAccount: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskExecutionStatus(
    typing_extensions.TypedDict, total=False
):
    latestJob: GoogleCloudDataplexV1Job
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskInfrastructureSpec(
    typing_extensions.TypedDict, total=False
):
    batch: GoogleCloudDataplexV1TaskInfrastructureSpecBatchComputeResources
    containerImage: GoogleCloudDataplexV1TaskInfrastructureSpecContainerImageRuntime
    vpcNetwork: GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork

@typing.type_check_only
class GoogleCloudDataplexV1TaskInfrastructureSpecBatchComputeResources(
    typing_extensions.TypedDict, total=False
):
    executorsCount: int
    maxExecutorsCount: int

@typing.type_check_only
class GoogleCloudDataplexV1TaskInfrastructureSpecContainerImageRuntime(
    typing_extensions.TypedDict, total=False
):
    image: str
    javaJars: _list[str]
    properties: dict[str, typing.Any]
    pythonPackages: _list[str]

@typing.type_check_only
class GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork(
    typing_extensions.TypedDict, total=False
):
    network: str
    networkTags: _list[str]
    subNetwork: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskNotebookTaskConfig(
    typing_extensions.TypedDict, total=False
):
    archiveUris: _list[str]
    fileUris: _list[str]
    infrastructureSpec: GoogleCloudDataplexV1TaskInfrastructureSpec
    notebook: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskSparkTaskConfig(
    typing_extensions.TypedDict, total=False
):
    archiveUris: _list[str]
    fileUris: _list[str]
    infrastructureSpec: GoogleCloudDataplexV1TaskInfrastructureSpec
    mainClass: str
    mainJarFileUri: str
    pythonScriptFile: str
    sqlScript: str
    sqlScriptFile: str

@typing.type_check_only
class GoogleCloudDataplexV1TaskTriggerSpec(typing_extensions.TypedDict, total=False):
    disabled: bool
    maxRetries: int
    schedule: str
    startTime: str
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "ON_DEMAND", "RECURRING"]

@typing.type_check_only
class GoogleCloudDataplexV1Zone(typing_extensions.TypedDict, total=False):
    assetStatus: GoogleCloudDataplexV1AssetStatus
    createTime: str
    description: str
    discoverySpec: GoogleCloudDataplexV1ZoneDiscoverySpec
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    resourceSpec: GoogleCloudDataplexV1ZoneResourceSpec
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "CREATING", "DELETING", "ACTION_REQUIRED"
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "RAW", "CURATED"]
    uid: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDataplexV1ZoneDiscoverySpec(typing_extensions.TypedDict, total=False):
    csvOptions: GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions
    enabled: bool
    excludePatterns: _list[str]
    includePatterns: _list[str]
    jsonOptions: GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions
    schedule: str

@typing.type_check_only
class GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions(
    typing_extensions.TypedDict, total=False
):
    delimiter: str
    disableTypeInference: bool
    encoding: str
    headerRows: int

@typing.type_check_only
class GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions(
    typing_extensions.TypedDict, total=False
):
    disableTypeInference: bool
    encoding: str

@typing.type_check_only
class GoogleCloudDataplexV1ZoneResourceSpec(typing_extensions.TypedDict, total=False):
    locationType: typing_extensions.Literal[
        "LOCATION_TYPE_UNSPECIFIED", "SINGLE_REGION", "MULTI_REGION"
    ]

@typing.type_check_only
class GoogleCloudLocationListLocationsResponse(
    typing_extensions.TypedDict, total=False
):
    locations: _list[GoogleCloudLocationLocation]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudLocationLocation(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class GoogleIamV1AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1Binding(typing_extensions.TypedDict, total=False):
    condition: GoogleTypeExpr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1AuditConfig]
    bindings: _list[GoogleIamV1Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleIamV1SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: GoogleIamV1Policy
    updateMask: str

@typing.type_check_only
class GoogleIamV1TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleLongrunningCancelOperationRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AllowedClient(typing_extensions.TypedDict, total=False):
    allowDev: bool
    allowSuid: bool
    allowedClientsCidr: str
    mountPermissions: typing_extensions.Literal[
        "MOUNT_PERMISSIONS_UNSPECIFIED", "READ", "READ_WRITE"
    ]
    network: str
    nfsPath: str
    noRootSquash: bool
    shareIp: str

@typing.type_check_only
class DetachLunRequest(typing_extensions.TypedDict, total=False):
    lun: str
    skipReboot: bool

@typing.type_check_only
class DisableInteractiveSerialConsoleRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnableInteractiveSerialConsoleRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class FetchInstanceProvisioningSettingsResponse(
    typing_extensions.TypedDict, total=False
):
    images: _list[OSImage]

@typing.type_check_only
class GoogleCloudBaremetalsolutionV2LogicalInterface(
    typing_extensions.TypedDict, total=False
):
    interfaceIndex: int
    logicalNetworkInterfaces: _list[LogicalNetworkInterface]
    name: str

@typing.type_check_only
class GoogleCloudBaremetalsolutionV2ServerNetworkTemplateLogicalInterface(
    typing_extensions.TypedDict, total=False
):
    name: str
    required: bool
    type: typing_extensions.Literal["INTERFACE_TYPE_UNSPECIFIED", "BOND", "NIC"]

@typing.type_check_only
class Instance(typing_extensions.TypedDict, total=False):
    createTime: str
    hyperthreadingEnabled: bool
    id: str
    interactiveSerialConsoleEnabled: bool
    labels: dict[str, typing.Any]
    logicalInterfaces: _list[GoogleCloudBaremetalsolutionV2LogicalInterface]
    loginInfo: str
    luns: _list[Lun]
    machineType: str
    name: str
    networkTemplate: str
    networks: _list[Network]
    osImage: str
    pod: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PROVISIONING",
        "RUNNING",
        "DELETED",
        "UPDATING",
        "STARTING",
        "STOPPING",
        "SHUTDOWN",
    ]
    updateTime: str
    volumes: _list[Volume]

@typing.type_check_only
class InstanceConfig(typing_extensions.TypedDict, total=False):
    accountNetworksEnabled: bool
    clientNetwork: NetworkAddress
    hyperthreading: bool
    id: str
    instanceType: str
    logicalInterfaces: _list[GoogleCloudBaremetalsolutionV2LogicalInterface]
    name: str
    networkConfig: typing_extensions.Literal[
        "NETWORKCONFIG_UNSPECIFIED", "SINGLE_VLAN", "MULTI_VLAN"
    ]
    networkTemplate: str
    osImage: str
    privateNetwork: NetworkAddress
    userNote: str

@typing.type_check_only
class InstanceQuota(typing_extensions.TypedDict, total=False):
    availableMachineCount: int
    gcpService: str
    instanceType: str
    location: str
    name: str

@typing.type_check_only
class IntakeVlanAttachment(typing_extensions.TypedDict, total=False):
    id: str
    pairingKey: str

@typing.type_check_only
class ListInstancesResponse(typing_extensions.TypedDict, total=False):
    instances: _list[Instance]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListLunsResponse(typing_extensions.TypedDict, total=False):
    luns: _list[Lun]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListNetworkUsageResponse(typing_extensions.TypedDict, total=False):
    networks: _list[NetworkUsage]

@typing.type_check_only
class ListNetworksResponse(typing_extensions.TypedDict, total=False):
    networks: _list[Network]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListNfsSharesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    nfsShares: _list[NfsShare]
    unreachable: _list[str]

@typing.type_check_only
class ListProvisioningQuotasResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    provisioningQuotas: _list[ProvisioningQuota]

@typing.type_check_only
class ListSSHKeysResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    sshKeys: _list[SSHKey]

@typing.type_check_only
class ListVolumesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    unreachable: _list[str]
    volumes: _list[Volume]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class LogicalNetworkInterface(typing_extensions.TypedDict, total=False):
    defaultGateway: bool
    id: str
    ipAddress: str
    network: str
    networkType: typing_extensions.Literal["TYPE_UNSPECIFIED", "CLIENT", "PRIVATE"]

@typing.type_check_only
class Lun(typing_extensions.TypedDict, total=False):
    bootLun: bool
    id: str
    multiprotocolType: typing_extensions.Literal[
        "MULTIPROTOCOL_TYPE_UNSPECIFIED", "LINUX"
    ]
    name: str
    shareable: bool
    sizeGb: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "UPDATING", "READY", "DELETING"
    ]
    storageType: typing_extensions.Literal["STORAGE_TYPE_UNSPECIFIED", "SSD", "HDD"]
    storageVolume: str
    wwid: str

@typing.type_check_only
class LunRange(typing_extensions.TypedDict, total=False):
    quantity: int
    sizeGb: int

@typing.type_check_only
class Network(typing_extensions.TypedDict, total=False):
    cidr: str
    gatewayIp: str
    id: str
    ipAddress: str
    jumboFramesEnabled: bool
    labels: dict[str, typing.Any]
    macAddress: _list[str]
    mountPoints: _list[NetworkMountPoint]
    name: str
    pod: str
    reservations: _list[NetworkAddressReservation]
    servicesCidr: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PROVISIONING", "PROVISIONED", "DEPROVISIONING", "UPDATING"
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "CLIENT", "PRIVATE"]
    vlanId: str
    vrf: VRF

@typing.type_check_only
class NetworkAddress(typing_extensions.TypedDict, total=False):
    address: str
    existingNetworkId: str
    networkId: str

@typing.type_check_only
class NetworkAddressReservation(typing_extensions.TypedDict, total=False):
    endAddress: str
    note: str
    startAddress: str

@typing.type_check_only
class NetworkConfig(typing_extensions.TypedDict, total=False):
    bandwidth: typing_extensions.Literal[
        "BANDWIDTH_UNSPECIFIED", "BW_1_GBPS", "BW_2_GBPS", "BW_5_GBPS", "BW_10_GBPS"
    ]
    cidr: str
    gcpService: str
    id: str
    jumboFramesEnabled: bool
    name: str
    serviceCidr: typing_extensions.Literal[
        "SERVICE_CIDR_UNSPECIFIED", "DISABLED", "HIGH_26", "HIGH_27", "HIGH_28"
    ]
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "CLIENT", "PRIVATE"]
    userNote: str
    vlanAttachments: _list[IntakeVlanAttachment]
    vlanSameProject: bool

@typing.type_check_only
class NetworkMountPoint(typing_extensions.TypedDict, total=False):
    defaultGateway: bool
    instance: str
    ipAddress: str
    logicalInterface: str

@typing.type_check_only
class NetworkUsage(typing_extensions.TypedDict, total=False):
    network: Network
    usedIps: _list[str]

@typing.type_check_only
class NfsExport(typing_extensions.TypedDict, total=False):
    allowDev: bool
    allowSuid: bool
    cidr: str
    machineId: str
    networkId: str
    noRootSquash: bool
    permissions: typing_extensions.Literal[
        "PERMISSIONS_UNSPECIFIED", "READ_ONLY", "READ_WRITE"
    ]

@typing.type_check_only
class NfsShare(typing_extensions.TypedDict, total=False):
    allowedClients: _list[AllowedClient]
    id: str
    labels: dict[str, typing.Any]
    name: str
    nfsShareId: str
    requestedSizeGib: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PROVISIONED", "CREATING", "UPDATING", "DELETING"
    ]
    storageType: typing_extensions.Literal["STORAGE_TYPE_UNSPECIFIED", "SSD", "HDD"]
    volume: str

@typing.type_check_only
class OSImage(typing_extensions.TypedDict, total=False):
    applicableInstanceTypes: _list[str]
    code: str
    description: str
    name: str
    supportedNetworkTemplates: _list[ServerNetworkTemplate]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class ProvisioningConfig(typing_extensions.TypedDict, total=False):
    cloudConsoleUri: str
    customId: str
    email: str
    handoverServiceAccount: str
    instances: _list[InstanceConfig]
    location: str
    name: str
    networks: _list[NetworkConfig]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "DRAFT",
        "SUBMITTED",
        "PROVISIONING",
        "PROVISIONED",
        "VALIDATED",
        "CANCELLED",
        "FAILED",
    ]
    statusMessage: str
    ticketId: str
    updateTime: str
    volumes: _list[VolumeConfig]
    vpcScEnabled: bool

@typing.type_check_only
class ProvisioningQuota(typing_extensions.TypedDict, total=False):
    assetType: typing_extensions.Literal[
        "ASSET_TYPE_UNSPECIFIED",
        "ASSET_TYPE_SERVER",
        "ASSET_TYPE_STORAGE",
        "ASSET_TYPE_NETWORK",
    ]
    availableCount: int
    gcpService: str
    instanceQuota: InstanceQuota
    location: str
    name: str
    networkBandwidth: str
    serverCount: str
    storageGib: str

@typing.type_check_only
class QosPolicy(typing_extensions.TypedDict, total=False):
    bandwidthGbps: float

@typing.type_check_only
class ResetInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ResizeVolumeRequest(typing_extensions.TypedDict, total=False):
    sizeGib: str

@typing.type_check_only
class SSHKey(typing_extensions.TypedDict, total=False):
    name: str
    publicKey: str

@typing.type_check_only
class ServerNetworkTemplate(typing_extensions.TypedDict, total=False):
    applicableInstanceTypes: _list[str]
    logicalInterfaces: _list[
        GoogleCloudBaremetalsolutionV2ServerNetworkTemplateLogicalInterface
    ]
    name: str

@typing.type_check_only
class SnapshotReservationDetail(typing_extensions.TypedDict, total=False):
    reservedSpaceGib: str
    reservedSpacePercent: int
    reservedSpaceRemainingGib: str
    reservedSpaceUsedPercent: int

@typing.type_check_only
class StartInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StopInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SubmitProvisioningConfigRequest(typing_extensions.TypedDict, total=False):
    email: str
    provisioningConfig: ProvisioningConfig

@typing.type_check_only
class SubmitProvisioningConfigResponse(typing_extensions.TypedDict, total=False):
    provisioningConfig: ProvisioningConfig

@typing.type_check_only
class VRF(typing_extensions.TypedDict, total=False):
    name: str
    qosPolicy: QosPolicy
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "PROVISIONING", "PROVISIONED"]
    vlanAttachments: _list[VlanAttachment]

@typing.type_check_only
class VlanAttachment(typing_extensions.TypedDict, total=False):
    id: str
    pairingKey: str
    peerIp: str
    peerVlanId: str
    qosPolicy: QosPolicy
    routerIp: str

@typing.type_check_only
class Volume(typing_extensions.TypedDict, total=False):
    autoGrownSizeGib: str
    bootVolume: bool
    currentSizeGib: str
    emergencySizeGib: str
    id: str
    labels: dict[str, typing.Any]
    maxSizeGib: str
    name: str
    notes: str
    originallyRequestedSizeGib: str
    performanceTier: typing_extensions.Literal[
        "VOLUME_PERFORMANCE_TIER_UNSPECIFIED",
        "VOLUME_PERFORMANCE_TIER_SHARED",
        "VOLUME_PERFORMANCE_TIER_ASSIGNED",
        "VOLUME_PERFORMANCE_TIER_HT",
    ]
    pod: str
    protocol: typing_extensions.Literal["PROTOCOL_UNSPECIFIED", "FIBRE_CHANNEL", "NFS"]
    remainingSpaceGib: str
    requestedSizeGib: str
    snapshotAutoDeleteBehavior: typing_extensions.Literal[
        "SNAPSHOT_AUTO_DELETE_BEHAVIOR_UNSPECIFIED",
        "DISABLED",
        "OLDEST_FIRST",
        "NEWEST_FIRST",
    ]
    snapshotEnabled: bool
    snapshotReservationDetail: SnapshotReservationDetail
    snapshotSchedulePolicy: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "READY", "DELETING", "UPDATING"
    ]
    storageType: typing_extensions.Literal["STORAGE_TYPE_UNSPECIFIED", "SSD", "HDD"]

@typing.type_check_only
class VolumeConfig(typing_extensions.TypedDict, total=False):
    gcpService: str
    id: str
    lunRanges: _list[LunRange]
    machineIds: _list[str]
    name: str
    nfsExports: _list[NfsExport]
    performanceTier: typing_extensions.Literal[
        "VOLUME_PERFORMANCE_TIER_UNSPECIFIED",
        "VOLUME_PERFORMANCE_TIER_SHARED",
        "VOLUME_PERFORMANCE_TIER_ASSIGNED",
        "VOLUME_PERFORMANCE_TIER_HT",
    ]
    protocol: typing_extensions.Literal[
        "PROTOCOL_UNSPECIFIED", "PROTOCOL_FC", "PROTOCOL_NFS"
    ]
    sizeGb: int
    snapshotsEnabled: bool
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "FLASH", "DISK"]
    userNote: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AffineTransform(typing_extensions.TypedDict, total=False):
    scaleX: float
    scaleY: float
    shearX: float
    shearY: float
    translateX: float
    translateY: float
    unit: typing_extensions.Literal["UNIT_UNSPECIFIED", "EMU", "PT"]

@typing.type_check_only
class AutoText(typing_extensions.TypedDict, total=False):
    content: str
    style: TextStyle
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "SLIDE_NUMBER"]

@typing.type_check_only
class Autofit(typing_extensions.TypedDict, total=False):
    autofitType: typing_extensions.Literal[
        "AUTOFIT_TYPE_UNSPECIFIED", "NONE", "TEXT_AUTOFIT", "SHAPE_AUTOFIT"
    ]
    fontScale: float
    lineSpacingReduction: float

@typing.type_check_only
class BatchUpdatePresentationRequest(typing_extensions.TypedDict, total=False):
    requests: _list[Request]
    writeControl: WriteControl

@typing.type_check_only
class BatchUpdatePresentationResponse(typing_extensions.TypedDict, total=False):
    presentationId: str
    replies: _list[Response]
    writeControl: WriteControl

@typing.type_check_only
class Bullet(typing_extensions.TypedDict, total=False):
    bulletStyle: TextStyle
    glyph: str
    listId: str
    nestingLevel: int

@typing.type_check_only
class ColorScheme(typing_extensions.TypedDict, total=False):
    colors: _list[ThemeColorPair]

@typing.type_check_only
class ColorStop(typing_extensions.TypedDict, total=False):
    alpha: float
    color: OpaqueColor
    position: float

@typing.type_check_only
class CreateImageRequest(typing_extensions.TypedDict, total=False):
    elementProperties: PageElementProperties
    objectId: str
    url: str

@typing.type_check_only
class CreateImageResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateLineRequest(typing_extensions.TypedDict, total=False):
    category: typing_extensions.Literal[
        "LINE_CATEGORY_UNSPECIFIED", "STRAIGHT", "BENT", "CURVED"
    ]
    elementProperties: PageElementProperties
    lineCategory: typing_extensions.Literal["STRAIGHT", "BENT", "CURVED"]
    objectId: str

@typing.type_check_only
class CreateLineResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateParagraphBulletsRequest(typing_extensions.TypedDict, total=False):
    bulletPreset: typing_extensions.Literal[
        "BULLET_DISC_CIRCLE_SQUARE",
        "BULLET_DIAMONDX_ARROW3D_SQUARE",
        "BULLET_CHECKBOX",
        "BULLET_ARROW_DIAMOND_DISC",
        "BULLET_STAR_CIRCLE_SQUARE",
        "BULLET_ARROW3D_CIRCLE_SQUARE",
        "BULLET_LEFTTRIANGLE_DIAMOND_DISC",
        "BULLET_DIAMONDX_HOLLOWDIAMOND_SQUARE",
        "BULLET_DIAMOND_CIRCLE_SQUARE",
        "NUMBERED_DIGIT_ALPHA_ROMAN",
        "NUMBERED_DIGIT_ALPHA_ROMAN_PARENS",
        "NUMBERED_DIGIT_NESTED",
        "NUMBERED_UPPERALPHA_ALPHA_ROMAN",
        "NUMBERED_UPPERROMAN_UPPERALPHA_DIGIT",
        "NUMBERED_ZERODIGIT_ALPHA_ROMAN",
    ]
    cellLocation: TableCellLocation
    objectId: str
    textRange: Range

@typing.type_check_only
class CreateShapeRequest(typing_extensions.TypedDict, total=False):
    elementProperties: PageElementProperties
    objectId: str
    shapeType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "TEXT_BOX",
        "RECTANGLE",
        "ROUND_RECTANGLE",
        "ELLIPSE",
        "ARC",
        "BENT_ARROW",
        "BENT_UP_ARROW",
        "BEVEL",
        "BLOCK_ARC",
        "BRACE_PAIR",
        "BRACKET_PAIR",
        "CAN",
        "CHEVRON",
        "CHORD",
        "CLOUD",
        "CORNER",
        "CUBE",
        "CURVED_DOWN_ARROW",
        "CURVED_LEFT_ARROW",
        "CURVED_RIGHT_ARROW",
        "CURVED_UP_ARROW",
        "DECAGON",
        "DIAGONAL_STRIPE",
        "DIAMOND",
        "DODECAGON",
        "DONUT",
        "DOUBLE_WAVE",
        "DOWN_ARROW",
        "DOWN_ARROW_CALLOUT",
        "FOLDED_CORNER",
        "FRAME",
        "HALF_FRAME",
        "HEART",
        "HEPTAGON",
        "HEXAGON",
        "HOME_PLATE",
        "HORIZONTAL_SCROLL",
        "IRREGULAR_SEAL_1",
        "IRREGULAR_SEAL_2",
        "LEFT_ARROW",
        "LEFT_ARROW_CALLOUT",
        "LEFT_BRACE",
        "LEFT_BRACKET",
        "LEFT_RIGHT_ARROW",
        "LEFT_RIGHT_ARROW_CALLOUT",
        "LEFT_RIGHT_UP_ARROW",
        "LEFT_UP_ARROW",
        "LIGHTNING_BOLT",
        "MATH_DIVIDE",
        "MATH_EQUAL",
        "MATH_MINUS",
        "MATH_MULTIPLY",
        "MATH_NOT_EQUAL",
        "MATH_PLUS",
        "MOON",
        "NO_SMOKING",
        "NOTCHED_RIGHT_ARROW",
        "OCTAGON",
        "PARALLELOGRAM",
        "PENTAGON",
        "PIE",
        "PLAQUE",
        "PLUS",
        "QUAD_ARROW",
        "QUAD_ARROW_CALLOUT",
        "RIBBON",
        "RIBBON_2",
        "RIGHT_ARROW",
        "RIGHT_ARROW_CALLOUT",
        "RIGHT_BRACE",
        "RIGHT_BRACKET",
        "ROUND_1_RECTANGLE",
        "ROUND_2_DIAGONAL_RECTANGLE",
        "ROUND_2_SAME_RECTANGLE",
        "RIGHT_TRIANGLE",
        "SMILEY_FACE",
        "SNIP_1_RECTANGLE",
        "SNIP_2_DIAGONAL_RECTANGLE",
        "SNIP_2_SAME_RECTANGLE",
        "SNIP_ROUND_RECTANGLE",
        "STAR_10",
        "STAR_12",
        "STAR_16",
        "STAR_24",
        "STAR_32",
        "STAR_4",
        "STAR_5",
        "STAR_6",
        "STAR_7",
        "STAR_8",
        "STRIPED_RIGHT_ARROW",
        "SUN",
        "TRAPEZOID",
        "TRIANGLE",
        "UP_ARROW",
        "UP_ARROW_CALLOUT",
        "UP_DOWN_ARROW",
        "UTURN_ARROW",
        "VERTICAL_SCROLL",
        "WAVE",
        "WEDGE_ELLIPSE_CALLOUT",
        "WEDGE_RECTANGLE_CALLOUT",
        "WEDGE_ROUND_RECTANGLE_CALLOUT",
        "FLOW_CHART_ALTERNATE_PROCESS",
        "FLOW_CHART_COLLATE",
        "FLOW_CHART_CONNECTOR",
        "FLOW_CHART_DECISION",
        "FLOW_CHART_DELAY",
        "FLOW_CHART_DISPLAY",
        "FLOW_CHART_DOCUMENT",
        "FLOW_CHART_EXTRACT",
        "FLOW_CHART_INPUT_OUTPUT",
        "FLOW_CHART_INTERNAL_STORAGE",
        "FLOW_CHART_MAGNETIC_DISK",
        "FLOW_CHART_MAGNETIC_DRUM",
        "FLOW_CHART_MAGNETIC_TAPE",
        "FLOW_CHART_MANUAL_INPUT",
        "FLOW_CHART_MANUAL_OPERATION",
        "FLOW_CHART_MERGE",
        "FLOW_CHART_MULTIDOCUMENT",
        "FLOW_CHART_OFFLINE_STORAGE",
        "FLOW_CHART_OFFPAGE_CONNECTOR",
        "FLOW_CHART_ONLINE_STORAGE",
        "FLOW_CHART_OR",
        "FLOW_CHART_PREDEFINED_PROCESS",
        "FLOW_CHART_PREPARATION",
        "FLOW_CHART_PROCESS",
        "FLOW_CHART_PUNCHED_CARD",
        "FLOW_CHART_PUNCHED_TAPE",
        "FLOW_CHART_SORT",
        "FLOW_CHART_SUMMING_JUNCTION",
        "FLOW_CHART_TERMINATOR",
        "ARROW_EAST",
        "ARROW_NORTH_EAST",
        "ARROW_NORTH",
        "SPEECH",
        "STARBURST",
        "TEARDROP",
        "ELLIPSE_RIBBON",
        "ELLIPSE_RIBBON_2",
        "CLOUD_CALLOUT",
        "CUSTOM",
    ]

@typing.type_check_only
class CreateShapeResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateSheetsChartRequest(typing_extensions.TypedDict, total=False):
    chartId: int
    elementProperties: PageElementProperties
    linkingMode: typing_extensions.Literal["NOT_LINKED_IMAGE", "LINKED"]
    objectId: str
    spreadsheetId: str

@typing.type_check_only
class CreateSheetsChartResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateSlideRequest(typing_extensions.TypedDict, total=False):
    insertionIndex: int
    objectId: str
    placeholderIdMappings: _list[LayoutPlaceholderIdMapping]
    slideLayoutReference: LayoutReference

@typing.type_check_only
class CreateSlideResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateTableRequest(typing_extensions.TypedDict, total=False):
    columns: int
    elementProperties: PageElementProperties
    objectId: str
    rows: int

@typing.type_check_only
class CreateTableResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CreateVideoRequest(typing_extensions.TypedDict, total=False):
    elementProperties: PageElementProperties
    id: str
    objectId: str
    source: typing_extensions.Literal["SOURCE_UNSPECIFIED", "YOUTUBE", "DRIVE"]

@typing.type_check_only
class CreateVideoResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class CropProperties(typing_extensions.TypedDict, total=False):
    angle: float
    bottomOffset: float
    leftOffset: float
    rightOffset: float
    topOffset: float

@typing.type_check_only
class DeleteObjectRequest(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class DeleteParagraphBulletsRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    objectId: str
    textRange: Range

@typing.type_check_only
class DeleteTableColumnRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    tableObjectId: str

@typing.type_check_only
class DeleteTableRowRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    tableObjectId: str

@typing.type_check_only
class DeleteTextRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    objectId: str
    textRange: Range

@typing.type_check_only
class Dimension(typing_extensions.TypedDict, total=False):
    magnitude: float
    unit: typing_extensions.Literal["UNIT_UNSPECIFIED", "EMU", "PT"]

@typing.type_check_only
class DuplicateObjectRequest(typing_extensions.TypedDict, total=False):
    objectId: str
    objectIds: dict[str, typing.Any]

@typing.type_check_only
class DuplicateObjectResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class Group(typing_extensions.TypedDict, total=False):
    children: _list[PageElement]

@typing.type_check_only
class GroupObjectsRequest(typing_extensions.TypedDict, total=False):
    childrenObjectIds: _list[str]
    groupObjectId: str

@typing.type_check_only
class GroupObjectsResponse(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    contentUrl: str
    imageProperties: ImageProperties
    placeholder: Placeholder
    sourceUrl: str

@typing.type_check_only
class ImageProperties(typing_extensions.TypedDict, total=False):
    brightness: float
    contrast: float
    cropProperties: CropProperties
    link: Link
    outline: Outline
    recolor: Recolor
    shadow: Shadow
    transparency: float

@typing.type_check_only
class InsertTableColumnsRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    insertRight: bool
    number: int
    tableObjectId: str

@typing.type_check_only
class InsertTableRowsRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    insertBelow: bool
    number: int
    tableObjectId: str

@typing.type_check_only
class InsertTextRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    insertionIndex: int
    objectId: str
    text: str

@typing.type_check_only
class LayoutPlaceholderIdMapping(typing_extensions.TypedDict, total=False):
    layoutPlaceholder: Placeholder
    layoutPlaceholderObjectId: str
    objectId: str

@typing.type_check_only
class LayoutProperties(typing_extensions.TypedDict, total=False):
    displayName: str
    masterObjectId: str
    name: str

@typing.type_check_only
class LayoutReference(typing_extensions.TypedDict, total=False):
    layoutId: str
    predefinedLayout: typing_extensions.Literal[
        "PREDEFINED_LAYOUT_UNSPECIFIED",
        "BLANK",
        "CAPTION_ONLY",
        "TITLE",
        "TITLE_AND_BODY",
        "TITLE_AND_TWO_COLUMNS",
        "TITLE_ONLY",
        "SECTION_HEADER",
        "SECTION_TITLE_AND_DESCRIPTION",
        "ONE_COLUMN_TEXT",
        "MAIN_POINT",
        "BIG_NUMBER",
    ]

@typing.type_check_only
class Line(typing_extensions.TypedDict, total=False):
    lineCategory: typing_extensions.Literal[
        "LINE_CATEGORY_UNSPECIFIED", "STRAIGHT", "BENT", "CURVED"
    ]
    lineProperties: LineProperties
    lineType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "STRAIGHT_CONNECTOR_1",
        "BENT_CONNECTOR_2",
        "BENT_CONNECTOR_3",
        "BENT_CONNECTOR_4",
        "BENT_CONNECTOR_5",
        "CURVED_CONNECTOR_2",
        "CURVED_CONNECTOR_3",
        "CURVED_CONNECTOR_4",
        "CURVED_CONNECTOR_5",
        "STRAIGHT_LINE",
    ]

@typing.type_check_only
class LineConnection(typing_extensions.TypedDict, total=False):
    connectedObjectId: str
    connectionSiteIndex: int

@typing.type_check_only
class LineFill(typing_extensions.TypedDict, total=False):
    solidFill: SolidFill

@typing.type_check_only
class LineProperties(typing_extensions.TypedDict, total=False):
    dashStyle: typing_extensions.Literal[
        "DASH_STYLE_UNSPECIFIED",
        "SOLID",
        "DOT",
        "DASH",
        "DASH_DOT",
        "LONG_DASH",
        "LONG_DASH_DOT",
    ]
    endArrow: typing_extensions.Literal[
        "ARROW_STYLE_UNSPECIFIED",
        "NONE",
        "STEALTH_ARROW",
        "FILL_ARROW",
        "FILL_CIRCLE",
        "FILL_SQUARE",
        "FILL_DIAMOND",
        "OPEN_ARROW",
        "OPEN_CIRCLE",
        "OPEN_SQUARE",
        "OPEN_DIAMOND",
    ]
    endConnection: LineConnection
    lineFill: LineFill
    link: Link
    startArrow: typing_extensions.Literal[
        "ARROW_STYLE_UNSPECIFIED",
        "NONE",
        "STEALTH_ARROW",
        "FILL_ARROW",
        "FILL_CIRCLE",
        "FILL_SQUARE",
        "FILL_DIAMOND",
        "OPEN_ARROW",
        "OPEN_CIRCLE",
        "OPEN_SQUARE",
        "OPEN_DIAMOND",
    ]
    startConnection: LineConnection
    weight: Dimension

@typing.type_check_only
class Link(typing_extensions.TypedDict, total=False):
    pageObjectId: str
    relativeLink: typing_extensions.Literal[
        "RELATIVE_SLIDE_LINK_UNSPECIFIED",
        "NEXT_SLIDE",
        "PREVIOUS_SLIDE",
        "FIRST_SLIDE",
        "LAST_SLIDE",
    ]
    slideIndex: int
    url: str

@typing.type_check_only
class List(typing_extensions.TypedDict, total=False):
    listId: str
    nestingLevel: dict[str, typing.Any]

@typing.type_check_only
class MasterProperties(typing_extensions.TypedDict, total=False):
    displayName: str

@typing.type_check_only
class MergeTableCellsRequest(typing_extensions.TypedDict, total=False):
    objectId: str
    tableRange: TableRange

@typing.type_check_only
class NestingLevel(typing_extensions.TypedDict, total=False):
    bulletStyle: TextStyle

@typing.type_check_only
class NotesProperties(typing_extensions.TypedDict, total=False):
    speakerNotesObjectId: str

@typing.type_check_only
class OpaqueColor(typing_extensions.TypedDict, total=False):
    rgbColor: RgbColor
    themeColor: typing_extensions.Literal[
        "THEME_COLOR_TYPE_UNSPECIFIED",
        "DARK1",
        "LIGHT1",
        "DARK2",
        "LIGHT2",
        "ACCENT1",
        "ACCENT2",
        "ACCENT3",
        "ACCENT4",
        "ACCENT5",
        "ACCENT6",
        "HYPERLINK",
        "FOLLOWED_HYPERLINK",
        "TEXT1",
        "BACKGROUND1",
        "TEXT2",
        "BACKGROUND2",
    ]

@typing.type_check_only
class OptionalColor(typing_extensions.TypedDict, total=False):
    opaqueColor: OpaqueColor

@typing.type_check_only
class Outline(typing_extensions.TypedDict, total=False):
    dashStyle: typing_extensions.Literal[
        "DASH_STYLE_UNSPECIFIED",
        "SOLID",
        "DOT",
        "DASH",
        "DASH_DOT",
        "LONG_DASH",
        "LONG_DASH_DOT",
    ]
    outlineFill: OutlineFill
    propertyState: typing_extensions.Literal["RENDERED", "NOT_RENDERED", "INHERIT"]
    weight: Dimension

@typing.type_check_only
class OutlineFill(typing_extensions.TypedDict, total=False):
    solidFill: SolidFill

@typing.type_check_only
class Page(typing_extensions.TypedDict, total=False):
    layoutProperties: LayoutProperties
    masterProperties: MasterProperties
    notesProperties: NotesProperties
    objectId: str
    pageElements: _list[PageElement]
    pageProperties: PageProperties
    pageType: typing_extensions.Literal[
        "SLIDE", "MASTER", "LAYOUT", "NOTES", "NOTES_MASTER"
    ]
    revisionId: str
    slideProperties: SlideProperties

@typing.type_check_only
class PageBackgroundFill(typing_extensions.TypedDict, total=False):
    propertyState: typing_extensions.Literal["RENDERED", "NOT_RENDERED", "INHERIT"]
    solidFill: SolidFill
    stretchedPictureFill: StretchedPictureFill

@typing.type_check_only
class PageElement(typing_extensions.TypedDict, total=False):
    description: str
    elementGroup: Group
    image: Image
    line: Line
    objectId: str
    shape: Shape
    sheetsChart: SheetsChart
    size: Size
    table: Table
    title: str
    transform: AffineTransform
    video: Video
    wordArt: WordArt

@typing.type_check_only
class PageElementProperties(typing_extensions.TypedDict, total=False):
    pageObjectId: str
    size: Size
    transform: AffineTransform

@typing.type_check_only
class PageProperties(typing_extensions.TypedDict, total=False):
    colorScheme: ColorScheme
    pageBackgroundFill: PageBackgroundFill

@typing.type_check_only
class ParagraphMarker(typing_extensions.TypedDict, total=False):
    bullet: Bullet
    style: ParagraphStyle

@typing.type_check_only
class ParagraphStyle(typing_extensions.TypedDict, total=False):
    alignment: typing_extensions.Literal[
        "ALIGNMENT_UNSPECIFIED", "START", "CENTER", "END", "JUSTIFIED"
    ]
    direction: typing_extensions.Literal[
        "TEXT_DIRECTION_UNSPECIFIED", "LEFT_TO_RIGHT", "RIGHT_TO_LEFT"
    ]
    indentEnd: Dimension
    indentFirstLine: Dimension
    indentStart: Dimension
    lineSpacing: float
    spaceAbove: Dimension
    spaceBelow: Dimension
    spacingMode: typing_extensions.Literal[
        "SPACING_MODE_UNSPECIFIED", "NEVER_COLLAPSE", "COLLAPSE_LISTS"
    ]

@typing.type_check_only
class Placeholder(typing_extensions.TypedDict, total=False):
    index: int
    parentObjectId: str
    type: typing_extensions.Literal[
        "NONE",
        "BODY",
        "CHART",
        "CLIP_ART",
        "CENTERED_TITLE",
        "DIAGRAM",
        "DATE_AND_TIME",
        "FOOTER",
        "HEADER",
        "MEDIA",
        "OBJECT",
        "PICTURE",
        "SLIDE_NUMBER",
        "SUBTITLE",
        "TABLE",
        "TITLE",
        "SLIDE_IMAGE",
    ]

@typing.type_check_only
class Presentation(typing_extensions.TypedDict, total=False):
    layouts: _list[Page]
    locale: str
    masters: _list[Page]
    notesMaster: Page
    pageSize: Size
    presentationId: str
    revisionId: str
    slides: _list[Page]
    title: str

@typing.type_check_only
class Range(typing_extensions.TypedDict, total=False):
    endIndex: int
    startIndex: int
    type: typing_extensions.Literal[
        "RANGE_TYPE_UNSPECIFIED", "FIXED_RANGE", "FROM_START_INDEX", "ALL"
    ]

@typing.type_check_only
class Recolor(typing_extensions.TypedDict, total=False):
    name: typing_extensions.Literal[
        "NONE",
        "LIGHT1",
        "LIGHT2",
        "LIGHT3",
        "LIGHT4",
        "LIGHT5",
        "LIGHT6",
        "LIGHT7",
        "LIGHT8",
        "LIGHT9",
        "LIGHT10",
        "DARK1",
        "DARK2",
        "DARK3",
        "DARK4",
        "DARK5",
        "DARK6",
        "DARK7",
        "DARK8",
        "DARK9",
        "DARK10",
        "GRAYSCALE",
        "NEGATIVE",
        "SEPIA",
        "CUSTOM",
    ]
    recolorStops: _list[ColorStop]

@typing.type_check_only
class RefreshSheetsChartRequest(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class ReplaceAllShapesWithImageRequest(typing_extensions.TypedDict, total=False):
    containsText: SubstringMatchCriteria
    imageReplaceMethod: typing_extensions.Literal[
        "IMAGE_REPLACE_METHOD_UNSPECIFIED", "CENTER_INSIDE", "CENTER_CROP"
    ]
    imageUrl: str
    pageObjectIds: _list[str]
    replaceMethod: typing_extensions.Literal["CENTER_INSIDE", "CENTER_CROP"]

@typing.type_check_only
class ReplaceAllShapesWithImageResponse(typing_extensions.TypedDict, total=False):
    occurrencesChanged: int

@typing.type_check_only
class ReplaceAllShapesWithSheetsChartRequest(typing_extensions.TypedDict, total=False):
    chartId: int
    containsText: SubstringMatchCriteria
    linkingMode: typing_extensions.Literal["NOT_LINKED_IMAGE", "LINKED"]
    pageObjectIds: _list[str]
    spreadsheetId: str

@typing.type_check_only
class ReplaceAllShapesWithSheetsChartResponse(typing_extensions.TypedDict, total=False):
    occurrencesChanged: int

@typing.type_check_only
class ReplaceAllTextRequest(typing_extensions.TypedDict, total=False):
    containsText: SubstringMatchCriteria
    pageObjectIds: _list[str]
    replaceText: str

@typing.type_check_only
class ReplaceAllTextResponse(typing_extensions.TypedDict, total=False):
    occurrencesChanged: int

@typing.type_check_only
class ReplaceImageRequest(typing_extensions.TypedDict, total=False):
    imageObjectId: str
    imageReplaceMethod: typing_extensions.Literal[
        "IMAGE_REPLACE_METHOD_UNSPECIFIED", "CENTER_INSIDE", "CENTER_CROP"
    ]
    url: str

@typing.type_check_only
class Request(typing_extensions.TypedDict, total=False):
    createImage: CreateImageRequest
    createLine: CreateLineRequest
    createParagraphBullets: CreateParagraphBulletsRequest
    createShape: CreateShapeRequest
    createSheetsChart: CreateSheetsChartRequest
    createSlide: CreateSlideRequest
    createTable: CreateTableRequest
    createVideo: CreateVideoRequest
    deleteObject: DeleteObjectRequest
    deleteParagraphBullets: DeleteParagraphBulletsRequest
    deleteTableColumn: DeleteTableColumnRequest
    deleteTableRow: DeleteTableRowRequest
    deleteText: DeleteTextRequest
    duplicateObject: DuplicateObjectRequest
    groupObjects: GroupObjectsRequest
    insertTableColumns: InsertTableColumnsRequest
    insertTableRows: InsertTableRowsRequest
    insertText: InsertTextRequest
    mergeTableCells: MergeTableCellsRequest
    refreshSheetsChart: RefreshSheetsChartRequest
    replaceAllShapesWithImage: ReplaceAllShapesWithImageRequest
    replaceAllShapesWithSheetsChart: ReplaceAllShapesWithSheetsChartRequest
    replaceAllText: ReplaceAllTextRequest
    replaceImage: ReplaceImageRequest
    rerouteLine: RerouteLineRequest
    ungroupObjects: UngroupObjectsRequest
    unmergeTableCells: UnmergeTableCellsRequest
    updateImageProperties: UpdateImagePropertiesRequest
    updateLineCategory: UpdateLineCategoryRequest
    updateLineProperties: UpdateLinePropertiesRequest
    updatePageElementAltText: UpdatePageElementAltTextRequest
    updatePageElementTransform: UpdatePageElementTransformRequest
    updatePageElementsZOrder: UpdatePageElementsZOrderRequest
    updatePageProperties: UpdatePagePropertiesRequest
    updateParagraphStyle: UpdateParagraphStyleRequest
    updateShapeProperties: UpdateShapePropertiesRequest
    updateSlideProperties: UpdateSlidePropertiesRequest
    updateSlidesPosition: UpdateSlidesPositionRequest
    updateTableBorderProperties: UpdateTableBorderPropertiesRequest
    updateTableCellProperties: UpdateTableCellPropertiesRequest
    updateTableColumnProperties: UpdateTableColumnPropertiesRequest
    updateTableRowProperties: UpdateTableRowPropertiesRequest
    updateTextStyle: UpdateTextStyleRequest
    updateVideoProperties: UpdateVideoPropertiesRequest

@typing.type_check_only
class RerouteLineRequest(typing_extensions.TypedDict, total=False):
    objectId: str

@typing.type_check_only
class Response(typing_extensions.TypedDict, total=False):
    createImage: CreateImageResponse
    createLine: CreateLineResponse
    createShape: CreateShapeResponse
    createSheetsChart: CreateSheetsChartResponse
    createSlide: CreateSlideResponse
    createTable: CreateTableResponse
    createVideo: CreateVideoResponse
    duplicateObject: DuplicateObjectResponse
    groupObjects: GroupObjectsResponse
    replaceAllShapesWithImage: ReplaceAllShapesWithImageResponse
    replaceAllShapesWithSheetsChart: ReplaceAllShapesWithSheetsChartResponse
    replaceAllText: ReplaceAllTextResponse

@typing.type_check_only
class RgbColor(typing_extensions.TypedDict, total=False):
    blue: float
    green: float
    red: float

@typing.type_check_only
class Shadow(typing_extensions.TypedDict, total=False):
    alignment: typing_extensions.Literal[
        "RECTANGLE_POSITION_UNSPECIFIED",
        "TOP_LEFT",
        "TOP_CENTER",
        "TOP_RIGHT",
        "LEFT_CENTER",
        "CENTER",
        "RIGHT_CENTER",
        "BOTTOM_LEFT",
        "BOTTOM_CENTER",
        "BOTTOM_RIGHT",
    ]
    alpha: float
    blurRadius: Dimension
    color: OpaqueColor
    propertyState: typing_extensions.Literal["RENDERED", "NOT_RENDERED", "INHERIT"]
    rotateWithShape: bool
    transform: AffineTransform
    type: typing_extensions.Literal["SHADOW_TYPE_UNSPECIFIED", "OUTER"]

@typing.type_check_only
class Shape(typing_extensions.TypedDict, total=False):
    placeholder: Placeholder
    shapeProperties: ShapeProperties
    shapeType: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "TEXT_BOX",
        "RECTANGLE",
        "ROUND_RECTANGLE",
        "ELLIPSE",
        "ARC",
        "BENT_ARROW",
        "BENT_UP_ARROW",
        "BEVEL",
        "BLOCK_ARC",
        "BRACE_PAIR",
        "BRACKET_PAIR",
        "CAN",
        "CHEVRON",
        "CHORD",
        "CLOUD",
        "CORNER",
        "CUBE",
        "CURVED_DOWN_ARROW",
        "CURVED_LEFT_ARROW",
        "CURVED_RIGHT_ARROW",
        "CURVED_UP_ARROW",
        "DECAGON",
        "DIAGONAL_STRIPE",
        "DIAMOND",
        "DODECAGON",
        "DONUT",
        "DOUBLE_WAVE",
        "DOWN_ARROW",
        "DOWN_ARROW_CALLOUT",
        "FOLDED_CORNER",
        "FRAME",
        "HALF_FRAME",
        "HEART",
        "HEPTAGON",
        "HEXAGON",
        "HOME_PLATE",
        "HORIZONTAL_SCROLL",
        "IRREGULAR_SEAL_1",
        "IRREGULAR_SEAL_2",
        "LEFT_ARROW",
        "LEFT_ARROW_CALLOUT",
        "LEFT_BRACE",
        "LEFT_BRACKET",
        "LEFT_RIGHT_ARROW",
        "LEFT_RIGHT_ARROW_CALLOUT",
        "LEFT_RIGHT_UP_ARROW",
        "LEFT_UP_ARROW",
        "LIGHTNING_BOLT",
        "MATH_DIVIDE",
        "MATH_EQUAL",
        "MATH_MINUS",
        "MATH_MULTIPLY",
        "MATH_NOT_EQUAL",
        "MATH_PLUS",
        "MOON",
        "NO_SMOKING",
        "NOTCHED_RIGHT_ARROW",
        "OCTAGON",
        "PARALLELOGRAM",
        "PENTAGON",
        "PIE",
        "PLAQUE",
        "PLUS",
        "QUAD_ARROW",
        "QUAD_ARROW_CALLOUT",
        "RIBBON",
        "RIBBON_2",
        "RIGHT_ARROW",
        "RIGHT_ARROW_CALLOUT",
        "RIGHT_BRACE",
        "RIGHT_BRACKET",
        "ROUND_1_RECTANGLE",
        "ROUND_2_DIAGONAL_RECTANGLE",
        "ROUND_2_SAME_RECTANGLE",
        "RIGHT_TRIANGLE",
        "SMILEY_FACE",
        "SNIP_1_RECTANGLE",
        "SNIP_2_DIAGONAL_RECTANGLE",
        "SNIP_2_SAME_RECTANGLE",
        "SNIP_ROUND_RECTANGLE",
        "STAR_10",
        "STAR_12",
        "STAR_16",
        "STAR_24",
        "STAR_32",
        "STAR_4",
        "STAR_5",
        "STAR_6",
        "STAR_7",
        "STAR_8",
        "STRIPED_RIGHT_ARROW",
        "SUN",
        "TRAPEZOID",
        "TRIANGLE",
        "UP_ARROW",
        "UP_ARROW_CALLOUT",
        "UP_DOWN_ARROW",
        "UTURN_ARROW",
        "VERTICAL_SCROLL",
        "WAVE",
        "WEDGE_ELLIPSE_CALLOUT",
        "WEDGE_RECTANGLE_CALLOUT",
        "WEDGE_ROUND_RECTANGLE_CALLOUT",
        "FLOW_CHART_ALTERNATE_PROCESS",
        "FLOW_CHART_COLLATE",
        "FLOW_CHART_CONNECTOR",
        "FLOW_CHART_DECISION",
        "FLOW_CHART_DELAY",
        "FLOW_CHART_DISPLAY",
        "FLOW_CHART_DOCUMENT",
        "FLOW_CHART_EXTRACT",
        "FLOW_CHART_INPUT_OUTPUT",
        "FLOW_CHART_INTERNAL_STORAGE",
        "FLOW_CHART_MAGNETIC_DISK",
        "FLOW_CHART_MAGNETIC_DRUM",
        "FLOW_CHART_MAGNETIC_TAPE",
        "FLOW_CHART_MANUAL_INPUT",
        "FLOW_CHART_MANUAL_OPERATION",
        "FLOW_CHART_MERGE",
        "FLOW_CHART_MULTIDOCUMENT",
        "FLOW_CHART_OFFLINE_STORAGE",
        "FLOW_CHART_OFFPAGE_CONNECTOR",
        "FLOW_CHART_ONLINE_STORAGE",
        "FLOW_CHART_OR",
        "FLOW_CHART_PREDEFINED_PROCESS",
        "FLOW_CHART_PREPARATION",
        "FLOW_CHART_PROCESS",
        "FLOW_CHART_PUNCHED_CARD",
        "FLOW_CHART_PUNCHED_TAPE",
        "FLOW_CHART_SORT",
        "FLOW_CHART_SUMMING_JUNCTION",
        "FLOW_CHART_TERMINATOR",
        "ARROW_EAST",
        "ARROW_NORTH_EAST",
        "ARROW_NORTH",
        "SPEECH",
        "STARBURST",
        "TEARDROP",
        "ELLIPSE_RIBBON",
        "ELLIPSE_RIBBON_2",
        "CLOUD_CALLOUT",
        "CUSTOM",
    ]
    text: TextContent

@typing.type_check_only
class ShapeBackgroundFill(typing_extensions.TypedDict, total=False):
    propertyState: typing_extensions.Literal["RENDERED", "NOT_RENDERED", "INHERIT"]
    solidFill: SolidFill

@typing.type_check_only
class ShapeProperties(typing_extensions.TypedDict, total=False):
    autofit: Autofit
    contentAlignment: typing_extensions.Literal[
        "CONTENT_ALIGNMENT_UNSPECIFIED",
        "CONTENT_ALIGNMENT_UNSUPPORTED",
        "TOP",
        "MIDDLE",
        "BOTTOM",
    ]
    link: Link
    outline: Outline
    shadow: Shadow
    shapeBackgroundFill: ShapeBackgroundFill

@typing.type_check_only
class SheetsChart(typing_extensions.TypedDict, total=False):
    chartId: int
    contentUrl: str
    sheetsChartProperties: SheetsChartProperties
    spreadsheetId: str

@typing.type_check_only
class SheetsChartProperties(typing_extensions.TypedDict, total=False):
    chartImageProperties: ImageProperties

@typing.type_check_only
class Size(typing_extensions.TypedDict, total=False):
    height: Dimension
    width: Dimension

@typing.type_check_only
class SlideProperties(typing_extensions.TypedDict, total=False):
    isSkipped: bool
    layoutObjectId: str
    masterObjectId: str
    notesPage: Page

@typing.type_check_only
class SolidFill(typing_extensions.TypedDict, total=False):
    alpha: float
    color: OpaqueColor

@typing.type_check_only
class StretchedPictureFill(typing_extensions.TypedDict, total=False):
    contentUrl: str
    size: Size

@typing.type_check_only
class SubstringMatchCriteria(typing_extensions.TypedDict, total=False):
    matchCase: bool
    text: str

@typing.type_check_only
class Table(typing_extensions.TypedDict, total=False):
    columns: int
    horizontalBorderRows: _list[TableBorderRow]
    rows: int
    tableColumns: _list[TableColumnProperties]
    tableRows: _list[TableRow]
    verticalBorderRows: _list[TableBorderRow]

@typing.type_check_only
class TableBorderCell(typing_extensions.TypedDict, total=False):
    location: TableCellLocation
    tableBorderProperties: TableBorderProperties

@typing.type_check_only
class TableBorderFill(typing_extensions.TypedDict, total=False):
    solidFill: SolidFill

@typing.type_check_only
class TableBorderProperties(typing_extensions.TypedDict, total=False):
    dashStyle: typing_extensions.Literal[
        "DASH_STYLE_UNSPECIFIED",
        "SOLID",
        "DOT",
        "DASH",
        "DASH_DOT",
        "LONG_DASH",
        "LONG_DASH_DOT",
    ]
    tableBorderFill: TableBorderFill
    weight: Dimension

@typing.type_check_only
class TableBorderRow(typing_extensions.TypedDict, total=False):
    tableBorderCells: _list[TableBorderCell]

@typing.type_check_only
class TableCell(typing_extensions.TypedDict, total=False):
    columnSpan: int
    location: TableCellLocation
    rowSpan: int
    tableCellProperties: TableCellProperties
    text: TextContent

@typing.type_check_only
class TableCellBackgroundFill(typing_extensions.TypedDict, total=False):
    propertyState: typing_extensions.Literal["RENDERED", "NOT_RENDERED", "INHERIT"]
    solidFill: SolidFill

@typing.type_check_only
class TableCellLocation(typing_extensions.TypedDict, total=False):
    columnIndex: int
    rowIndex: int

@typing.type_check_only
class TableCellProperties(typing_extensions.TypedDict, total=False):
    contentAlignment: typing_extensions.Literal[
        "CONTENT_ALIGNMENT_UNSPECIFIED",
        "CONTENT_ALIGNMENT_UNSUPPORTED",
        "TOP",
        "MIDDLE",
        "BOTTOM",
    ]
    tableCellBackgroundFill: TableCellBackgroundFill

@typing.type_check_only
class TableColumnProperties(typing_extensions.TypedDict, total=False):
    columnWidth: Dimension

@typing.type_check_only
class TableRange(typing_extensions.TypedDict, total=False):
    columnSpan: int
    location: TableCellLocation
    rowSpan: int

@typing.type_check_only
class TableRow(typing_extensions.TypedDict, total=False):
    rowHeight: Dimension
    tableCells: _list[TableCell]
    tableRowProperties: TableRowProperties

@typing.type_check_only
class TableRowProperties(typing_extensions.TypedDict, total=False):
    minRowHeight: Dimension

@typing.type_check_only
class TextContent(typing_extensions.TypedDict, total=False):
    lists: dict[str, typing.Any]
    textElements: _list[TextElement]

@typing.type_check_only
class TextElement(typing_extensions.TypedDict, total=False):
    autoText: AutoText
    endIndex: int
    paragraphMarker: ParagraphMarker
    startIndex: int
    textRun: TextRun

@typing.type_check_only
class TextRun(typing_extensions.TypedDict, total=False):
    content: str
    style: TextStyle

@typing.type_check_only
class TextStyle(typing_extensions.TypedDict, total=False):
    backgroundColor: OptionalColor
    baselineOffset: typing_extensions.Literal[
        "BASELINE_OFFSET_UNSPECIFIED", "NONE", "SUPERSCRIPT", "SUBSCRIPT"
    ]
    bold: bool
    fontFamily: str
    fontSize: Dimension
    foregroundColor: OptionalColor
    italic: bool
    link: Link
    smallCaps: bool
    strikethrough: bool
    underline: bool
    weightedFontFamily: WeightedFontFamily

@typing.type_check_only
class ThemeColorPair(typing_extensions.TypedDict, total=False):
    color: RgbColor
    type: typing_extensions.Literal[
        "THEME_COLOR_TYPE_UNSPECIFIED",
        "DARK1",
        "LIGHT1",
        "DARK2",
        "LIGHT2",
        "ACCENT1",
        "ACCENT2",
        "ACCENT3",
        "ACCENT4",
        "ACCENT5",
        "ACCENT6",
        "HYPERLINK",
        "FOLLOWED_HYPERLINK",
        "TEXT1",
        "BACKGROUND1",
        "TEXT2",
        "BACKGROUND2",
    ]

@typing.type_check_only
class Thumbnail(typing_extensions.TypedDict, total=False):
    contentUrl: str
    height: int
    width: int

@typing.type_check_only
class UngroupObjectsRequest(typing_extensions.TypedDict, total=False):
    objectIds: _list[str]

@typing.type_check_only
class UnmergeTableCellsRequest(typing_extensions.TypedDict, total=False):
    objectId: str
    tableRange: TableRange

@typing.type_check_only
class UpdateImagePropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    imageProperties: ImageProperties
    objectId: str

@typing.type_check_only
class UpdateLineCategoryRequest(typing_extensions.TypedDict, total=False):
    lineCategory: typing_extensions.Literal[
        "LINE_CATEGORY_UNSPECIFIED", "STRAIGHT", "BENT", "CURVED"
    ]
    objectId: str

@typing.type_check_only
class UpdateLinePropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    lineProperties: LineProperties
    objectId: str

@typing.type_check_only
class UpdatePageElementAltTextRequest(typing_extensions.TypedDict, total=False):
    description: str
    objectId: str
    title: str

@typing.type_check_only
class UpdatePageElementTransformRequest(typing_extensions.TypedDict, total=False):
    applyMode: typing_extensions.Literal[
        "APPLY_MODE_UNSPECIFIED", "RELATIVE", "ABSOLUTE"
    ]
    objectId: str
    transform: AffineTransform

@typing.type_check_only
class UpdatePageElementsZOrderRequest(typing_extensions.TypedDict, total=False):
    operation: typing_extensions.Literal[
        "Z_ORDER_OPERATION_UNSPECIFIED",
        "BRING_TO_FRONT",
        "BRING_FORWARD",
        "SEND_BACKWARD",
        "SEND_TO_BACK",
    ]
    pageElementObjectIds: _list[str]

@typing.type_check_only
class UpdatePagePropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    pageProperties: PageProperties

@typing.type_check_only
class UpdateParagraphStyleRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    fields: str
    objectId: str
    style: ParagraphStyle
    textRange: Range

@typing.type_check_only
class UpdateShapePropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    shapeProperties: ShapeProperties

@typing.type_check_only
class UpdateSlidePropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    slideProperties: SlideProperties

@typing.type_check_only
class UpdateSlidesPositionRequest(typing_extensions.TypedDict, total=False):
    insertionIndex: int
    slideObjectIds: _list[str]

@typing.type_check_only
class UpdateTableBorderPropertiesRequest(typing_extensions.TypedDict, total=False):
    borderPosition: typing_extensions.Literal[
        "ALL",
        "BOTTOM",
        "INNER",
        "INNER_HORIZONTAL",
        "INNER_VERTICAL",
        "LEFT",
        "OUTER",
        "RIGHT",
        "TOP",
    ]
    fields: str
    objectId: str
    tableBorderProperties: TableBorderProperties
    tableRange: TableRange

@typing.type_check_only
class UpdateTableCellPropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    tableCellProperties: TableCellProperties
    tableRange: TableRange

@typing.type_check_only
class UpdateTableColumnPropertiesRequest(typing_extensions.TypedDict, total=False):
    columnIndices: _list[int]
    fields: str
    objectId: str
    tableColumnProperties: TableColumnProperties

@typing.type_check_only
class UpdateTableRowPropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    rowIndices: _list[int]
    tableRowProperties: TableRowProperties

@typing.type_check_only
class UpdateTextStyleRequest(typing_extensions.TypedDict, total=False):
    cellLocation: TableCellLocation
    fields: str
    objectId: str
    style: TextStyle
    textRange: Range

@typing.type_check_only
class UpdateVideoPropertiesRequest(typing_extensions.TypedDict, total=False):
    fields: str
    objectId: str
    videoProperties: VideoProperties

@typing.type_check_only
class Video(typing_extensions.TypedDict, total=False):
    id: str
    source: typing_extensions.Literal["SOURCE_UNSPECIFIED", "YOUTUBE", "DRIVE"]
    url: str
    videoProperties: VideoProperties

@typing.type_check_only
class VideoProperties(typing_extensions.TypedDict, total=False):
    autoPlay: bool
    end: int
    mute: bool
    outline: Outline
    start: int

@typing.type_check_only
class WeightedFontFamily(typing_extensions.TypedDict, total=False):
    fontFamily: str
    weight: int

@typing.type_check_only
class WordArt(typing_extensions.TypedDict, total=False):
    renderedText: str

@typing.type_check_only
class WriteControl(typing_extensions.TypedDict, total=False):
    requiredRevisionId: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudShellResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class EnvironmentsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class PublicKeysResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: CreatePublicKeyRequest = ...,
                    **kwargs: typing.Any
                ) -> PublicKeyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...

            def authorize(
                self,
                *,
                name: str,
                body: AuthorizeEnvironmentRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> EnvironmentHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: Environment = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> EnvironmentHttpRequest: ...
            def start(
                self,
                *,
                name: str,
                body: StartEnvironmentRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def publicKeys(self) -> PublicKeysResource: ...

        def environments(self) -> EnvironmentsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class EnvironmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Environment: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PublicKeyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublicKey: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Accelerator(typing_extensions.TypedDict, total=False):
    acceleratorType: typing_extensions.Literal[
        "ACCELERATOR_TYPE_UNSPECIFIED", "CDC", "HEALTHCARE", "CCAI_INSIGHTS"
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ENABLED", "DISABLED", "UNKNOWN"
    ]

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CryptoKeyConfig(typing_extensions.TypedDict, total=False):
    keyReference: str

@typing.type_check_only
class DnsPeering(typing_extensions.TypedDict, total=False):
    description: str
    domain: str
    name: str
    targetNetwork: str
    targetProject: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EventPublishConfig(typing_extensions.TypedDict, total=False):
    enabled: bool
    topic: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class Instance(typing_extensions.TypedDict, total=False):
    accelerators: _list[Accelerator]
    apiEndpoint: str
    availableVersion: _list[Version]
    createTime: str
    cryptoKeyConfig: CryptoKeyConfig
    dataprocServiceAccount: str
    description: str
    disabledReason: _list[str]
    displayName: str
    enableRbac: bool
    enableStackdriverLogging: bool
    enableStackdriverMonitoring: bool
    eventPublishConfig: EventPublishConfig
    gcsBucket: str
    labels: dict[str, typing.Any]
    name: str
    networkConfig: NetworkConfig
    options: dict[str, typing.Any]
    p4ServiceAccount: str
    privateInstance: bool
    serviceAccount: str
    serviceEndpoint: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "CREATING",
        "ACTIVE",
        "FAILED",
        "DELETING",
        "UPGRADING",
        "RESTARTING",
        "UPDATING",
        "AUTO_UPDATING",
        "AUTO_UPGRADING",
        "DISABLED",
    ]
    stateMessage: str
    tenantProjectId: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "BASIC", "ENTERPRISE", "DEVELOPER"
    ]
    updateTime: str
    version: str
    zone: str

@typing.type_check_only
class ListAvailableVersionsResponse(typing_extensions.TypedDict, total=False):
    availableVersions: _list[Version]
    nextPageToken: str

@typing.type_check_only
class ListDnsPeeringsResponse(typing_extensions.TypedDict, total=False):
    dnsPeerings: _list[DnsPeering]
    nextPageToken: str

@typing.type_check_only
class ListInstancesResponse(typing_extensions.TypedDict, total=False):
    instances: _list[Instance]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class NetworkConfig(typing_extensions.TypedDict, total=False):
    ipAllocation: str
    network: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    additionalStatus: dict[str, typing.Any]
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class RestartInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class Version(typing_extensions.TypedDict, total=False):
    availableFeatures: _list[str]
    defaultVersion: bool
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "TYPE_PREVIEW", "TYPE_GENERAL_AVAILABILITY"
    ]
    versionNumber: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudSupportResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AttachmentsResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            parent: str,
            body: CreateAttachmentRequest = ...,
            **kwargs: typing.Any
        ) -> AttachmentHttpRequest: ...

    @typing.type_check_only
    class CaseClassificationsResource(googleapiclient.discovery.Resource):
        def search(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            query: str = ...,
            **kwargs: typing.Any
        ) -> SearchCaseClassificationsResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: SearchCaseClassificationsResponseHttpRequest,
            previous_response: SearchCaseClassificationsResponse,
        ) -> SearchCaseClassificationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class CasesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AttachmentsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAttachmentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAttachmentsResponseHttpRequest,
                previous_response: ListAttachmentsResponse,
            ) -> ListAttachmentsResponseHttpRequest | None: ...

        @typing.type_check_only
        class CommentsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: Comment = ..., **kwargs: typing.Any
            ) -> CommentHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListCommentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListCommentsResponseHttpRequest,
                previous_response: ListCommentsResponse,
            ) -> ListCommentsResponseHttpRequest | None: ...

        def close(self, *, name: str, body: CloseCaseRequest = ..., **kwargs: typing.Any) -> CaseHttpRequest: ...  # type: ignore
        def create(
            self, *, parent: str, body: Case = ..., **kwargs: typing.Any
        ) -> CaseHttpRequest: ...
        def escalate(
            self, *, name: str, body: EscalateCaseRequest = ..., **kwargs: typing.Any
        ) -> CaseHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> CaseHttpRequest: ...
        def list(
            self,
            *,
            parent: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListCasesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCasesResponseHttpRequest,
            previous_response: ListCasesResponse,
        ) -> ListCasesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            name: str,
            body: Case = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> CaseHttpRequest: ...
        def search(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            query: str = ...,
            **kwargs: typing.Any
        ) -> SearchCasesResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: SearchCasesResponseHttpRequest,
            previous_response: SearchCasesResponse,
        ) -> SearchCasesResponseHttpRequest | None: ...
        def attachments(self) -> AttachmentsResource: ...
        def comments(self) -> CommentsResource: ...

    @typing.type_check_only
    class MediaResource(googleapiclient.discovery.Resource):
        def download(self, *, name: str, **kwargs: typing.Any) -> MediaHttpRequest: ...
        def download_media(
            self, *, name: str, **kwargs: typing.Any
        ) -> BytesHttpRequest: ...
        def upload(
            self,
            *,
            parent: str,
            body: CreateAttachmentRequest = ...,
            **kwargs: typing.Any
        ) -> AttachmentHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def attachments(self) -> AttachmentsResource: ...
    def caseClassifications(self) -> CaseClassificationsResource: ...
    def cases(self) -> CasesResource: ...
    def media(self) -> MediaResource: ...

@typing.type_check_only
class AttachmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Attachment: ...

@typing.type_check_only
class CaseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Case: ...

@typing.type_check_only
class CommentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Comment: ...

@typing.type_check_only
class ListAttachmentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAttachmentsResponse: ...

@typing.type_check_only
class ListCasesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCasesResponse: ...

@typing.type_check_only
class ListCommentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCommentsResponse: ...

@typing.type_check_only
class MediaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Media: ...

@typing.type_check_only
class SearchCaseClassificationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchCaseClassificationsResponse: ...

@typing.type_check_only
class SearchCasesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchCasesResponse: ...

@typing.type_check_only
class BytesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> bytes: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class AuthorizationCode(typing_extensions.TypedDict, total=False):
    code: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class ConfigureContactSettingsRequest(typing_extensions.TypedDict, total=False):
    contactNotices: _list[str]
    contactSettings: ContactSettings
    updateMask: str
    validateOnly: bool

@typing.type_check_only
class ConfigureDnsSettingsRequest(typing_extensions.TypedDict, total=False):
    dnsSettings: DnsSettings
    updateMask: str
    validateOnly: bool

@typing.type_check_only
class ConfigureManagementSettingsRequest(typing_extensions.TypedDict, total=False):
    managementSettings: ManagementSettings
    updateMask: str

@typing.type_check_only
class Contact(typing_extensions.TypedDict, total=False):
    email: str
    faxNumber: str
    phoneNumber: str
    postalAddress: PostalAddress

@typing.type_check_only
class ContactSettings(typing_extensions.TypedDict, total=False):
    adminContact: Contact
    privacy: typing_extensions.Literal[
        "CONTACT_PRIVACY_UNSPECIFIED",
        "PUBLIC_CONTACT_DATA",
        "PRIVATE_CONTACT_DATA",
        "REDACTED_CONTACT_DATA",
    ]
    registrantContact: Contact
    technicalContact: Contact

@typing.type_check_only
class CustomDns(typing_extensions.TypedDict, total=False):
    dsRecords: _list[DsRecord]
    nameServers: _list[str]

@typing.type_check_only
class DnsSettings(typing_extensions.TypedDict, total=False):
    customDns: CustomDns
    glueRecords: _list[GlueRecord]
    googleDomainsDns: GoogleDomainsDns

@typing.type_check_only
class Domain(typing_extensions.TypedDict, total=False):
    domainName: str
    resourceState: typing_extensions.Literal[
        "RESOURCE_STATE_UNSPECIFIED",
        "IMPORTABLE",
        "UNSUPPORTED",
        "SUSPENDED",
        "EXPIRED",
        "DELETED",
    ]
    yearlyPrice: Money

@typing.type_check_only
class DsRecord(typing_extensions.TypedDict, total=False):
    algorithm: typing_extensions.Literal[
        "ALGORITHM_UNSPECIFIED",
        "RSAMD5",
        "DH",
        "DSA",
        "ECC",
        "RSASHA1",
        "DSANSEC3SHA1",
        "RSASHA1NSEC3SHA1",
        "RSASHA256",
        "RSASHA512",
        "ECCGOST",
        "ECDSAP256SHA256",
        "ECDSAP384SHA384",
        "ED25519",
        "ED448",
        "INDIRECT",
        "PRIVATEDNS",
        "PRIVATEOID",
    ]
    digest: str
    digestType: typing_extensions.Literal[
        "DIGEST_TYPE_UNSPECIFIED", "SHA1", "SHA256", "GOST3411", "SHA384"
    ]
    keyTag: int

@typing.type_check_only
class ExportRegistrationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GlueRecord(typing_extensions.TypedDict, total=False):
    hostName: str
    ipv4Addresses: _list[str]
    ipv6Addresses: _list[str]

@typing.type_check_only
class GoogleDomainsDns(typing_extensions.TypedDict, total=False):
    dsRecords: _list[DsRecord]
    dsState: typing_extensions.Literal[
        "DS_STATE_UNSPECIFIED", "DS_RECORDS_UNPUBLISHED", "DS_RECORDS_PUBLISHED"
    ]
    nameServers: _list[str]

@typing.type_check_only
class ImportDomainRequest(typing_extensions.TypedDict, total=False):
    domainName: str
    labels: dict[str, typing.Any]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListRegistrationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    registrations: _list[Registration]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class ManagementSettings(typing_extensions.TypedDict, total=False):
    renewalMethod: typing_extensions.Literal[
        "RENEWAL_METHOD_UNSPECIFIED", "AUTOMATIC_RENEWAL", "MANUAL_RENEWAL"
    ]
    transferLockState: typing_extensions.Literal[
        "TRANSFER_LOCK_STATE_UNSPECIFIED", "UNLOCKED", "LOCKED"
    ]

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PostalAddress(typing_extensions.TypedDict, total=False):
    addressLines: _list[str]
    administrativeArea: str
    languageCode: str
    locality: str
    organization: str
    postalCode: str
    recipients: _list[str]
    regionCode: str
    revision: int
    sortingCode: str
    sublocality: str

@typing.type_check_only
class RegisterDomainRequest(typing_extensions.TypedDict, total=False):
    contactNotices: _list[str]
    domainNotices: _list[str]
    registration: Registration
    validateOnly: bool
    yearlyPrice: Money

@typing.type_check_only
class RegisterParameters(typing_extensions.TypedDict, total=False):
    availability: typing_extensions.Literal[
        "AVAILABILITY_UNSPECIFIED", "AVAILABLE", "UNAVAILABLE", "UNSUPPORTED", "UNKNOWN"
    ]
    domainName: str
    domainNotices: _list[str]
    supportedPrivacy: _list[str]
    yearlyPrice: Money

@typing.type_check_only
class Registration(typing_extensions.TypedDict, total=False):
    contactSettings: ContactSettings
    createTime: str
    dnsSettings: DnsSettings
    domainName: str
    expireTime: str
    issues: _list[str]
    labels: dict[str, typing.Any]
    managementSettings: ManagementSettings
    name: str
    pendingContactSettings: ContactSettings
    registerFailureReason: typing_extensions.Literal[
        "REGISTER_FAILURE_REASON_UNSPECIFIED",
        "REGISTER_FAILURE_REASON_UNKNOWN",
        "DOMAIN_NOT_AVAILABLE",
        "INVALID_CONTACTS",
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "REGISTRATION_PENDING",
        "REGISTRATION_FAILED",
        "TRANSFER_PENDING",
        "TRANSFER_FAILED",
        "IMPORT_PENDING",
        "ACTIVE",
        "SUSPENDED",
        "EXPORTED",
    ]
    supportedPrivacy: _list[str]
    transferFailureReason: typing_extensions.Literal[
        "TRANSFER_FAILURE_REASON_UNSPECIFIED",
        "TRANSFER_FAILURE_REASON_UNKNOWN",
        "EMAIL_CONFIRMATION_FAILURE",
        "DOMAIN_NOT_REGISTERED",
        "DOMAIN_HAS_TRANSFER_LOCK",
        "INVALID_AUTHORIZATION_CODE",
        "TRANSFER_CANCELLED",
        "TRANSFER_REJECTED",
        "INVALID_REGISTRANT_EMAIL_ADDRESS",
        "DOMAIN_NOT_ELIGIBLE_FOR_TRANSFER",
        "TRANSFER_ALREADY_PENDING",
    ]

@typing.type_check_only
class ResetAuthorizationCodeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RetrieveImportableDomainsResponse(typing_extensions.TypedDict, total=False):
    domains: _list[Domain]
    nextPageToken: str

@typing.type_check_only
class RetrieveRegisterParametersResponse(typing_extensions.TypedDict, total=False):
    registerParameters: RegisterParameters

@typing.type_check_only
class RetrieveTransferParametersResponse(typing_extensions.TypedDict, total=False):
    transferParameters: TransferParameters

@typing.type_check_only
class SearchDomainsResponse(typing_extensions.TypedDict, total=False):
    registerParameters: _list[RegisterParameters]

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TransferDomainRequest(typing_extensions.TypedDict, total=False):
    authorizationCode: AuthorizationCode
    contactNotices: _list[str]
    registration: Registration
    validateOnly: bool
    yearlyPrice: Money

@typing.type_check_only
class TransferParameters(typing_extensions.TypedDict, total=False):
    currentRegistrar: str
    currentRegistrarUri: str
    domainName: str
    nameServers: _list[str]
    supportedPrivacy: _list[str]
    transferLockState: typing_extensions.Literal[
        "TRANSFER_LOCK_STATE_UNSPECIFIED", "UNLOCKED", "LOCKED"
    ]
    yearlyPrice: Money



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DriveLabelsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LabelsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocksResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest,
                previous_response: GoogleAppsDriveLabelsV2betaListLabelLocksResponse,
            ) -> GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest | None: ...

        @typing.type_check_only
        class PermissionsResource(googleapiclient.discovery.Resource):
            def batchDelete(
                self,
                *,
                labelsId: str,
                body: GoogleAppsDriveLabelsV2betaBatchDeleteLabelPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def batchUpdate(
                self,
                *,
                parent: str,
                body: GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsResponseHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleAppsDriveLabelsV2betaLabelPermission = ...,
                useAdminAccess: bool = ...,
                **kwargs: typing.Any
            ) -> GoogleAppsDriveLabelsV2betaLabelPermissionHttpRequest: ...
            def delete(
                self, *, name: str, useAdminAccess: bool = ..., **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                useAdminAccess: bool = ...,
                **kwargs: typing.Any
            ) -> GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest,
                previous_response: GoogleAppsDriveLabelsV2betaListLabelPermissionsResponse,
            ) -> GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                parent: str,
                body: GoogleAppsDriveLabelsV2betaLabelPermission = ...,
                useAdminAccess: bool = ...,
                **kwargs: typing.Any
            ) -> GoogleAppsDriveLabelsV2betaLabelPermissionHttpRequest: ...

        @typing.type_check_only
        class RevisionsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class LocksResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest,
                    previous_response: GoogleAppsDriveLabelsV2betaListLabelLocksResponse,
                ) -> GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest | None: ...

            @typing.type_check_only
            class PermissionsResource(googleapiclient.discovery.Resource):
                def batchDelete(
                    self,
                    *,
                    labelsId: str,
                    revisionsId: str,
                    body: GoogleAppsDriveLabelsV2betaBatchDeleteLabelPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def batchUpdate(
                    self,
                    *,
                    parent: str,
                    body: GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsResponseHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleAppsDriveLabelsV2betaLabelPermission = ...,
                    useAdminAccess: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleAppsDriveLabelsV2betaLabelPermissionHttpRequest: ...
                def delete(
                    self, *, name: str, useAdminAccess: bool = ..., **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    useAdminAccess: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest,
                    previous_response: GoogleAppsDriveLabelsV2betaListLabelPermissionsResponse,
                ) -> GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    parent: str,
                    body: GoogleAppsDriveLabelsV2betaLabelPermission = ...,
                    useAdminAccess: bool = ...,
                    **kwargs: typing.Any
                ) -> GoogleAppsDriveLabelsV2betaLabelPermissionHttpRequest: ...

            def locks(self) -> LocksResource: ...
            def permissions(self) -> PermissionsResource: ...

        def create(
            self,
            *,
            body: GoogleAppsDriveLabelsV2betaLabel = ...,
            languageCode: str = ...,
            useAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def delete(
            self,
            *,
            name: str,
            useAdminAccess: bool = ...,
            writeControl_requiredRevisionId: str = ...,
            **kwargs: typing.Any
        ) -> GoogleProtobufEmptyHttpRequest: ...
        def delta(
            self,
            *,
            name: str,
            body: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseHttpRequest: ...
        def disable(
            self,
            *,
            name: str,
            body: GoogleAppsDriveLabelsV2betaDisableLabelRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def enable(
            self,
            *,
            name: str,
            body: GoogleAppsDriveLabelsV2betaEnableLabelRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def get(
            self,
            *,
            name: str,
            languageCode: str = ...,
            useAdminAccess: bool = ...,
            view: typing_extensions.Literal[
                "LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def list(
            self,
            *,
            languageCode: str = ...,
            minimumRole: typing_extensions.Literal[
                "LABEL_ROLE_UNSPECIFIED", "READER", "APPLIER", "ORGANIZER", "EDITOR"
            ] = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            publishedOnly: bool = ...,
            useAdminAccess: bool = ...,
            view: typing_extensions.Literal[
                "LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaListLabelsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleAppsDriveLabelsV2betaListLabelsResponseHttpRequest,
            previous_response: GoogleAppsDriveLabelsV2betaListLabelsResponse,
        ) -> GoogleAppsDriveLabelsV2betaListLabelsResponseHttpRequest | None: ...
        def publish(
            self,
            *,
            name: str,
            body: GoogleAppsDriveLabelsV2betaPublishLabelRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def updateLabelCopyMode(
            self,
            *,
            name: str,
            body: GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelHttpRequest: ...
        def locks(self) -> LocksResource: ...
        def permissions(self) -> PermissionsResource: ...
        def revisions(self) -> RevisionsResource: ...

    @typing.type_check_only
    class LimitsResource(googleapiclient.discovery.Resource):
        def getLabel(
            self, *, name: str = ..., **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaLabelLimitsHttpRequest: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        def getCapabilities(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleAppsDriveLabelsV2betaUserCapabilitiesHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def labels(self) -> LabelsResource: ...
    def limits(self) -> LimitsResource: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsResponse: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponse: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaLabel: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelLimitsHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaLabelLimits: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelPermissionHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaLabelPermission: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelLocksResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaListLabelLocksResponse: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaListLabelPermissionsResponse: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaListLabelsResponse: ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUserCapabilitiesHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleAppsDriveLabelsV2betaUserCapabilities: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...
